@@ -2,16 +2,16 @@ package Crypt::AuthEnc;
 
 use strict;
 use warnings;
-our $VERSION = '0.054_007';
+our $VERSION = '0.054_008';
 
 sub CLONE_SKIP { 1 } # prevent cloning
 
 1;
 
-__END__
+=pod
 
 =head1 NAME
 
 Crypt::AuthEnc - [internal only]
 
-=cut
\ No newline at end of file
+=cut
