@@ -2,7 +2,7 @@ package Crypt::Mac;
 
 use strict;
 use warnings;
-our $VERSION = '0.054_007';
+our $VERSION = '0.054_008';
 
 require Exporter; our @ISA = qw(Exporter); ### use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw( mac mac_hex )] );
@@ -50,10 +50,10 @@ sub CLONE_SKIP { 1 } # prevent cloning
 
 1;
 
-__END__
+=pod
 
 =head1 NAME
 
 Crypt::Mac - [internal only]
 
-=cut
\ No newline at end of file
+=cut
