@@ -2,7 +2,7 @@ package Crypt::Mode;
 
 use strict;
 use warnings;
-our $VERSION = '0.054_007';
+our $VERSION = '0.054_008';
 
 ### METHODS
 
@@ -63,10 +63,10 @@ sub CLONE_SKIP { 1 } # prevent cloning
 
 1;
 
-__END__
+=pod
 
 =head1 NAME
 
 Crypt::Mode - [internal only]
 
-=cut
\ No newline at end of file
+=cut
