@@ -2,7 +2,7 @@ package Crypt::PK;
 
 use strict;
 use warnings;
-our $VERSION = '0.054_007';
+our $VERSION = '0.054_008';
 
 use Carp;
 
@@ -24,10 +24,10 @@ sub _ssh_parse {
 
 1;
 
-__END__
+=pod
 
 =head1 NAME
 
 Crypt::PK - [internal only]
 
-=cut
\ No newline at end of file
+=cut
