@@ -2,7 +2,7 @@ package CryptX;
 
 use strict;
 use warnings ;
-our $VERSION = '0.054_007';
+our $VERSION = '0.054_008';
 
 use base qw(Exporter);
 our @EXPORT_OK = qw();
@@ -56,7 +56,8 @@ sub _encode_json {
 }
 
 1;
-__END__
+
+=pod
 
 =head1 NAME
 
@@ -115,7 +116,7 @@ L<Crypt::PK::RSA>, L<Crypt::PK::DSA>, L<Crypt::PK::ECC>, L<Crypt::PK::DH>
 
 L<Crypt::PRNG>, L<Crypt::PRNG::Fortuna>, L<Crypt::PRNG::Yarrow>, L<Crypt::PRNG::RC4>, L<Crypt::PRNG::Sober128>, L<Crypt::PRNG::ChaCha20>
 
-=item * Key derivation functions - PBKDF1, PBKFD2 and HKDF
+=item * Key derivation functions - PBKDF1, PBKDF2 and HKDF
 
 L<Crypt::KeyDerivation>
 
@@ -131,4 +132,6 @@ This program is free software; you can redistribute it and/or modify it under th
 
 =head1 COPYRIGHT
 
-Copyright (c) 2013+ DCIT, a.s. L<http://www.dcit.cz> / Karel Miko
\ No newline at end of file
+Copyright (c) 2013+ DCIT, a.s. L<http://www.dcit.cz> / Karel Miko
+
+=cut
